@@ -183,7 +183,9 @@ class WaveBank(_Bank):
         self.ext = ext
         self.bank_path = Path(base_path).absolute()
         # get waveforms structure based on structures of path and filename
-        self.path_structure = path_structure or WAVEFORM_STRUCTURE
+        self.path_structure = (
+            path_structure if path_structure is not None else WAVEFORM_STRUCTURE
+        )
         self.name_structure = name_structure or WAVEFORM_NAME_STRUCTURE
         self.executor = executor
         # initialize cache
@@ -323,10 +325,6 @@ class WaveBank(_Bank):
             kwargs are passed to pandas.read_hdf function
         """
         self.ensure_bank_path_exists()
-        if starttime is not None and endtime is not None:
-            if starttime > endtime:
-                msg = f"starttime cannot be greater than endtime."
-                raise ValueError(msg)
         if not self.index_path.exists():
             self.update_index()
         # if no file was created (dealing with empty bank) return empty index
