@@ -49,10 +49,10 @@ _DATETIME_TYPE_MAP = {"datetime64[ns]": np.int64, "timedelta64[ns]": np.int64}
 
 # columns required for station data
 STATION_DTYPES = OrderedDict(
-    network=str,
-    station=str,
-    location=str,
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     seed_id=str,
     latitude=float,
     longitude=float,
@@ -68,10 +68,10 @@ STATION_DTYPES = OrderedDict(
 STATION_COLUMNS = tuple(STATION_DTYPES)
 
 DF_TO_INV_DTYPES = OrderedDict(
-    network=str,
-    station=str,
-    location=str,
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     latitude=float,
     longitude=float,
     elevation=float,
@@ -145,10 +145,10 @@ PICK_DTYPES = OrderedDict(
     author=str,
     agency_id=str,
     event_id=str,
-    network=str,
-    station=str,
-    location="location_code",
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     uncertainty=float,
     lower_uncertainty=float,
     upper_uncertainty=float,
@@ -171,6 +171,8 @@ DISTANCE_COLUMN_INPUT_DTYPES = OrderedDict(
     latitude=float, longitude=float, elevation=float
 )
 
+ALT_DISTANCE_COLUMN_DTYPES = OrderedDict(latitude=float, longitude=float, depth=float)
+
 # DISTANCE_COLUMNS = tuple(DISTANCE_COLUMN_DTYPES)
 # DISTANCE_INPUT_COLUMNS = tuple(DISTANCE_COLUMN_INPUT_DTYPES)
 
@@ -199,28 +201,17 @@ AMPLITUDE_DTYPES = OrderedDict(
     agency_id=str,
     event_time="datetime64[ns]",
     event_id=str,
-    network=str,
-    station=str,
-    location=str,
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     uncertainty=float,
     lower_uncertainty=float,
     upper_uncertainty=float,
     confidence_level=float,
 )
 
-AMPLITUDE_COLUMNS = (
-    "resource_id",
-    "event_id",
-    "event_time",
-    "generic_amplitude",
-    "type",
-    "magnitude_hint",
-    "network",
-    "station",
-    "location",
-    "channel",
-)
+AMPLITUDE_COLUMNS = tuple(AMPLITUDE_DTYPES)
 
 # columns required for station magnitudes
 STATION_MAGNITUDE_DTYPES = OrderedDict(
@@ -237,24 +228,19 @@ STATION_MAGNITUDE_DTYPES = OrderedDict(
     agency_id=str,
     event_id=str,
     event_time="datetime64[ns]",
-    network=str,
-    station=str,
-    location=str,
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     uncertainty=float,
     lower_uncertainty=float,
     upper_uncertainty=float,
     confidence_level=float,
 )
 
-STATION_MAGNITUDE_COLUMNS = (
-    "resource_id",
-    "mag",
-    "station_magnitude_type",
-    "network",
-    "station",
-    "location",
-    "channel",
+# This is messy, but want to exclude the magnitude_id column
+STATION_MAGNITUDE_COLUMNS = tuple(
+    set(STATION_MAGNITUDE_DTYPES.keys()) - {"magnitude_id"}
 )
 
 # columns required for magnitudes
@@ -280,7 +266,7 @@ MAGNITUDE_DTYPES = OrderedDict(
     confidence_level=float,
 )
 
-MAGNITUDE_COLUMNS = ("resource_id", "event_id", "event_time", "mag", "magnitude_type")
+MAGNITUDE_COLUMNS = tuple(MAGNITUDE_DTYPES)
 
 # columns required for arrivals
 ARRIVAL_DTYPES = OrderedDict(
@@ -302,30 +288,15 @@ ARRIVAL_DTYPES = OrderedDict(
     creation_time="datetime64[ns]",
     author=str,
     agency_id=str,
-    network=str,
-    station=str,
-    location=str,
-    channel=str,
+    network="nslc_code",
+    station="nslc_code",
+    location="nslc_code",
+    channel="nslc_code",
     origin_id=str,
     origin_time="datetime64[ns]",
 )
 
-ARRIVAL_COLUMNS = (
-    "resource_id",
-    "origin_id",
-    "origin_time",
-    "pick_id",
-    "phase",
-    "time_residual",
-    "azimuth",
-    "distance",
-    "time_weight",
-    "time_correction",
-    "network",
-    "station",
-    "location",
-    "channel",
-)
+ARRIVAL_COLUMNS = tuple(ARRIVAL_DTYPES)
 
 # Waveform datatypes
 WAVEFORM_DTYPES = OrderedDict(
@@ -379,7 +350,18 @@ EMPTYTD64 = np.timedelta64(0, "s")
 OPSDATA_PATH = Path().home() / "opsdata"
 
 # Number of cores
-CPU_COUNT = cpu_count() or 4  # fallback to four is None is returned
+CPU_COUNT = cpu_count() or 4  # fallback to four if None is returned
+
+# supported read_hdf5 kwargs
+READ_HDF5_KWARGS = frozenset(
+    {"columns", "where", "mode", "errors", "start", "stop", "key", "chunksize"}
+)
+
+# keywords associated with get_events
+CIRCULAR_PARAMS = {"latitude", "longitude", "minradius", "maxradius", "degrees"}
+NONCIRCULAR_PARAMS = {"minlongitude", "maxlongitude", "minlatitude", "maxlatitude"}
+UNSUPPORTED_PARAMS = {"magnitude_type", "events", "contributor"}
+
 
 # ------------------- type aliases (aliai?)
 
@@ -532,6 +514,16 @@ EVENT_ATTRS = (
     "preferred_focal_mechanism_id",
 )
 
+# get_station kwargs which are UTCDateTime objects
+GET_STATIONS_UTC_KWARGS = (
+    "starttime",
+    "endtime",
+    "startbefore",
+    "startafter",
+    "endbefore",
+    "endafter",
+)
+
 # Numpy int types
 NUMPY_INT_TYPES = {
     np.int,
