@@ -494,7 +494,7 @@ def _objs_from_event(event, attr, extractor):
     """ return a dataframe of an obj type from an event """
     # ensure we have an iterable and flatten station_magnitudes
     cat = [event] if isinstance(event, ev.Event) else event
-    objs = [obj for e in cat for obj in e.__dict__[attr]]
+    objs = [obj for e in cat for obj in getattr(e, attr)]
     return extractor(objs, extras=_get_event_info(cat, attr))
 
 
@@ -559,6 +559,10 @@ def _get_uncertainty(errors):
 def _get_seed_id(obj):
     """ Strip nslc info for an extractor """
     seed_id = get_seed_id(obj)
+    split = seed_id.split(".")
+    if len(split) != 4:
+        msg = f"The seed_id: {seed_id} is not valid. It was found on {obj}"
+        raise ValueError(msg)
     dd = {x: y for x, y in zip(NSLC, seed_id.split("."))}
     return {"seed_id": seed_id, **dd}
 
