@@ -8,6 +8,7 @@ from collections import namedtuple
 from functools import partial
 from typing import Optional, Union, Callable, Tuple, Dict
 
+import numpy as np
 import obspy
 import pandas as pd
 from obspy import Stream
@@ -353,21 +354,31 @@ class Fetcher:
         cannot be obtained. For example, if reference='S' only events with some
         S picks will be yielded.
         """
-        if not reference.lower() in self.reference_funcs:
-            msg = (
-                f"reference of {reference} is not supported. Supported "
-                f"reference arguments are {list(self.reference_funcs)}"
-            )
-            raise ValueError(msg)
+
+        def _check_yield_event_waveform_(reference, ta, tb):
+            if not reference.lower() in self.reference_funcs:
+                msg = (
+                    f"reference of {reference} is not supported. Supported "
+                    f"reference arguments are {list(self.reference_funcs)}"
+                )
+                raise ValueError(msg)
+            if not (np.abs(tb) + np.abs(ta)) > np.timedelta64(0, "s"):
+                msg = (
+                    "time_before and/or time_after must be specified in either "
+                    "Fetcher's init or the yield_event_Waveforms call"
+                )
+                raise ValueError(msg)
+
         tb = to_timedelta64(time_before, default=self.time_before)
         ta = to_timedelta64(time_after, default=self.time_after)
-        assert (tb is not None) and (ta is not None)
+        _check_yield_event_waveform_(reference, ta, tb)
         # get reference times
         ref_func = self.reference_funcs[reference.lower()]
         reftime_df = ref_func(self)
         # if using a wavebank preload index over entire time-span for speedup
         if isinstance(self.waveform_client, WaveBank) and len(reftime_df):
-            mt, mx = reftime_df["time"].min(), reftime_df["time"].max()
+            mt = reftime_df["time"].min() - tb
+            mx = reftime_df["time"].max() + ta
             index = self.waveform_client.read_index(starttime=mt, endtime=mx)
             get_bulk_wf = partial(self._get_bulk_wf, index=index)
         else:
@@ -515,8 +526,16 @@ class Fetcher:
         df = inv[~(con1 | con2)].set_index("seed_id")[list(NSLC)]
         if df.empty:  # return empty list if no data found
             return []
-        df["starttime"] = starttime
-        df["endtime"] = endtime
+        if isinstance(starttime, pd.Series):
+            # Have to get clever here to make sure only active stations get used
+            # and indices are not duplicated.
+            new_start = starttime.loc[set(starttime.index).intersection(df.index)]
+            new_end = endtime.loc[set(endtime.index).intersection(df.index)]
+            df["starttime"] = new_start.loc[~new_start.index.duplicated()]
+            df["endtime"] = new_end.loc[~new_end.index.duplicated()]
+        else:
+            df["starttime"] = starttime
+            df["endtime"] = endtime
         # remove any rows that don't have defined start/end times
         out = df[~(df["starttime"].isnull() | df["endtime"].isnull())]
         # ensure we have UTCDateTime objects
